[Uclinux-h8-devel] [PATCH v2 04/11] m68k: switch to kernel_clone()

Zurück zum Archiv-Index
Christian Brauner chris****@ubunt*****
2020年 8月 19日 (水) 19:46:48 JST


The old _do_fork() helper is removed in favor of the new kernel_clone() helper.
The latter adheres to naming conventions for kernel internal syscall helpers.

Acked-by: Geert Uytterhoeven <geert****@linux*****>
Cc: Kars de Jong <jongk****@linux*****>
Cc: linux****@lists*****
Signed-off-by: Christian Brauner <chris****@ubunt*****>
---
/* v2 */
unchanged
---
 arch/m68k/kernel/process.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/arch/m68k/kernel/process.c b/arch/m68k/kernel/process.c
index 6492a2c54dbc..08359a6e058f 100644
--- a/arch/m68k/kernel/process.c
+++ b/arch/m68k/kernel/process.c
@@ -107,10 +107,10 @@ void flush_thread(void)
  * on top of pt_regs, which means that sys_clone() arguments would be
  * buried.  We could, of course, copy them, but it's too costly for no
  * good reason - generic clone() would have to copy them *again* for
  * _do_fork() anyway.  So in this case it's actually better to pass pt_regs *
  * and extract arguments for _do_fork() from there.  Eventually we might
  * go for calling _do_fork() directly from the wrapper, but only after we
  * are finished with _do_fork() prototype conversion.
  */
 asmlinkage int m68k_clone(struct pt_regs *regs)
 {
@@ -125,7 +125,7 @@ asmlinkage int m68k_clone(struct pt_regs *regs)
 		.tls		= regs->d5,
 	};
 
-	return _do_fork(&args);
+	return kernel_clone(&args);
 }
 
 /*
@@ -107,10 +107,10 @@ void flush_thread(void)
  * buried.  We could, of course, copy them, but it's too costly for no
  * good reason - generic clone() would have to copy them *again* for
- * _do_fork() anyway.  So in this case it's actually better to pass pt_regs *
- * and extract arguments for _do_fork() from there.  Eventually we might
- * go for calling _do_fork() directly from the wrapper, but only after we
- * are finished with _do_fork() prototype conversion.
+ * kernel_clone() anyway.  So in this case it's actually better to pass pt_regs *
+ * and extract arguments for kernel_clone() from there.  Eventually we might
+ * go for calling kernel_clone() directly from the wrapper, but only after we
+ * are finished with kernel_clone() prototype conversion.
  */
 asmlinkage int m68k_clone(struct pt_regs *regs)
-- 
2.28.0



Uclinux-h8-devel メーリングリストの案内
Zurück zum Archiv-Index